GutenbergCacheSettings

Struct GutenbergCacheSettings 

pub struct GutenbergCacheSettings {
    pub cache_rdf_download_link: String,
    pub cache_filename: String,
    pub cache_rdf_unpack_directory: String,
    pub cache_rdf_archive_name: String,
    pub text_files_cache_folder: String,
    pub db_in_memory: bool,
}
These are the essential settings for building your cache

Fields

cache_rdf_download_link: String

This is the link used to download the rdf tar archive of rdfs from gutenberg

cache_filename: String

This is the filename of the cache db

cache_rdf_unpack_directory: String

this is the directory used to unpack the rdf tar archive downloaded from gutenberg

cache_rdf_archive_name: String

this is the archive filename in which we download

text_files_cache_folder: String

this is the folder used to hold all the raw text data you download

db_in_memory: bool

this will make the cache in memory (it will not save it on disk), it is used in tests

Implementations